def find_missing(data):
    result = {}
    for col in data[0].keys():
        result[col] = sum(1 for row in data if row[col] == "")
    return result

def remove_duplicates(data):
    seen = set()
    unique = []
    for row in data:
        row_tuple = tuple(row.items())
        if row_tuple not in seen:
            seen.add(row_tuple)
            unique.append(row)
    return unique