def safe_float(value):
    try:
        return float(value)
    except:
        return None

def get_numeric_column(data, column):
    values = []
    for row in data:
        val = safe_float(row[column])
        if val is not None:
            values.append(val)
    return values